@@ -239,6 +239,16 @@ ClusteringAlgo <- function(xdata,
     }
   }
 
+  # Scaling the data
+  if (scale) {
+    xdata <- scale(xdata)
+  }
+
+  # Transposing if clustering of columns
+  if (!row) {
+    xdata <- t(xdata)
+  }
+
   # Applying user-defined function for variable selection
   out <- do.call(implementation, args = list(
     xdata = xdata,
@@ -246,7 +256,6 @@ ClusteringAlgo <- function(xdata,
     eps = eps,
     Lambda = Lambda,
     scale = scale,
-    row = row,
     ...
   ))
 
